package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.diagbot.dto.DeptInfoDTO;
import com.diagbot.entity.DeptInfo;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.DeptInfoServiceImpl;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.DateUtil;
import com.diagbot.util.ListUtil;
import com.diagbot.util.UserUtils;
import com.diagbot.vo.AddDeptInfoVO;
import com.diagbot.vo.GetDeptInfoDetialsVO;
import com.diagbot.vo.GetDeptInfoVO;
import com.diagbot.vo.UpdateDeptInfoVO;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2018/11/22 11:44
 */
@Component
public class DeptInfoFacade extends DeptInfoServiceImpl {

    /**
     * 添加科室信息
     * @param addDeptInfoVO
     * @return
     */
    public Boolean addDeptInfo(AddDeptInfoVO addDeptInfoVO) {
        QueryWrapper<DeptInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("is_deleted",IsDeleteEnum.N.getKey());
        queryWrapper.eq("name",addDeptInfoVO.getName());
        List<DeptInfo> deptInfoList = this.list(queryWrapper);
        if(ListUtil.isNotEmpty(deptInfoList)){
            throw new CommonException(CommonErrorCode.IS_EXISTS, "添加失败，科室已存在");
        }
        DeptInfo deptInfo = new DeptInfo();
        BeanUtil.copyProperties(addDeptInfoVO,deptInfo);
        Date now = DateUtil.now();
        String userId = UserUtils.getCurrentPrincipleID();
        deptInfo.setCreator(userId);
        deptInfo.setGmtCreate(now);
        deptInfo.setModifier(userId);
        this.save(deptInfo);
        return true;
    }

    /**
     * 修改科室信息
     * @param updateDeptInfoVO
     * @return
     */
    public Boolean updateDeptInfo(UpdateDeptInfoVO updateDeptInfoVO) {
        DeptInfo deptInfo =this.getById(updateDeptInfoVO.getId());
        BeanUtil.copyProperties(updateDeptInfoVO,deptInfo);
        deptInfo.setModifier(UserUtils.getCurrentPrincipleID());
        deptInfo.setGmtModified(DateUtil.now());
        this.updateById(deptInfo);
        return true;
    }

    /**
     * 删除科室信息
     * @param updateDeptInfoVO
     * @return
     */
    public Boolean deleteDeptInfo(UpdateDeptInfoVO updateDeptInfoVO) {
        DeptInfo deptInfo =new DeptInfo();
        BeanUtil.copyProperties(updateDeptInfoVO,deptInfo);
        deptInfo.setModifier(UserUtils.getCurrentPrincipleID());
        deptInfo.setIsDeleted(IsDeleteEnum.Y.getKey());
        deptInfo.setGmtModified(DateUtil.now());
        this.updateById(deptInfo);
        return true;
    }


    /**
     * 获取科室信息
     * @param getDeptInfoVO
     * @return
     */
    public IPage<DeptInfo> getDeptInfo(GetDeptInfoVO getDeptInfoVO){
        IPage iPage = this.getAllDeptInfo(getDeptInfoVO);
        return iPage;
    }

    /**
     * 常用标签维护获取科室名称
     * @return
     */
    public List<DeptInfoDTO> getAllDeptInfo(){
        List<DeptInfoDTO> deptInfoList = this.getDeptName();
        return deptInfoList;
    }

    /**
     * 科室维护详情
     * @param getDeptInfoDetialsVO
     * @return
     */
    public DeptInfo getDeptInfoDetials(GetDeptInfoDetialsVO getDeptInfoDetialsVO){
        DeptInfo deptInfo = this.getById(getDeptInfoDetialsVO.getId());
        return deptInfo;
    }
}
